@@ -26,22 +26,26 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 vbelts provides functions that allow the computation of complex factors in v-belt dimensioning."""
 
-import os
+# import os
 
-from . import service_factor
-from . import profile
-from . import diam
-from . import length
-from . import util
-from . import power
-from . import speed
-from . import force
+# import belt
+# import length
+# import util
+# import power
+# import speed
+# import pulley
 
-from .service_factor import *
-from .profile import *
-from .diam import *
-from .length import *
-from .util import *
-from .power import *
-from .speed import *
-from .force import *
+from vbelts import belt
+from vbelts import length
+from vbelts import util
+from vbelts import power
+from vbelts import speed
+from vbelts import pulley
+
+__all__ = ['belt', 'length', 'util', 'power', 'speed', 'pulley']
+
+# try:
+#     vbelts_dir = os.path.dirname(__file__)
+#     vbelts_data_dir = os.path.join(vbelts_dir, 'data')
+# except:
+#     pass
